@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Handel-Storage-RDBO/t/lib/Handel/Test.pm 1243 2008-01-20T04:05:18.816539Z claco  $
+# $Id$
 package Handel::Test;
 use strict;
 use warnings;
@@ -9,7 +9,7 @@ BEGIN {
     use Test::More;
     use File::Spec::Functions qw/catfile catdir/;
 
-    @Handel::Test::EXPORT = @Test::More::EXPORT;
+    @Handel::Test::EXPORT = (@Test::More::EXPORT, 'cmp_currency');
 
     __PACKAGE__->mk_group_accessors('inherited', qw/db_dir db_file/);
 };
@@ -142,4 +142,10 @@ sub populate_schema {
     };
 };
 
+sub cmp_currency {
+    my ($got, $expected, $test_name) = @_;
+
+    is( sprintf("%.2f", $got), sprintf("%.2f", $expected), $test_name);
+};
+
 1;
